# Pexels Website:   https://www.pexels.com
# class information:
#     Get json data from https://www.pexels.com
#     Search photos using Pexels API v1
#     Search popular photos using Pexels API v1
#     Search curated photos using Pexels API v1
import requests
from .src import Photo
from .src import Video
""" Class """
class API:
    def __init__(self, PEXELS_API):
        self.PEXELS_AUTHORIZATION = {"Authorization":PEXELS_API}
        self.request = None
        self.json = None
        self.page = None
        self.total_results = None
        self.photo_results = None
        self.video_results = None
        self.has_next_page = None
        self.has_previous_page = None
        self.next_page = None
        self.prev_page = None

    """ Returns json for the given query """
    def search_photos(self, query, results_per_page, page):
        query = query.replace(" ", "+")
        url = "https://api.pexels.com/v1/search?query={}&per_page={}&page={}".format(query, results_per_page, page)
        self.__request(url)
        # If there is no json data return None
        return None if not self.request else self.json

    """ Return json with popular photos of the current page """
    def popular_photos(self, results_per_page, page):
        url = "https://api.pexels.com/v1/popular?per_page={}&page={}".format(results_per_page, page)
        self.__request(url)
        # If there is no json data return None
        return None if not self.request else self.json

    """ Return json with curated photos of the current page """
    def curated_photos(self, results_per_page, page):
        url = "https://api.pexels.com/v1/curated?per_page={}&page={}".format(results_per_page, page)
        self.__request(url)
        # If there is no json data return None
        return None if not self.request else self.json

    """ Returns json for the given query """
    def search_videos(self, query, results_per_page=15, page=1):
        query = query.replace(" ", "+")
        url = "https://api.pexels.com/videos/search?query={}&per_page={}&page={}".format(query, results_per_page, page)
        self.__request(url)
        # If there is no json data return None
        return None if not self.request else self.json

    """ Return json with popular videos of the current page """
    def popular_videos(self, results_per_page, page):
        url = "https://api.pexels.com/videos/popular?per_page={}&page={}".format(results_per_page, page)
        self.__request(url)
        # If there is no json data return None
        return None if not self.request else self.json

    """ Return json with curated videos of the current page """
    def curated_videos(self, results_per_page, page):
        url = "https://api.pexels.com/videos/curated?per_page={}&page={}".format(results_per_page, page)
        self.__request(url)
        # If there is no json data return None
        return None if not self.request else self.json


    """ Returns json of the next page if available """
    def search_next_page(self):
        if self.has_next_page:
            self.__request(self.next_page)
        else:
            return None
        # If there is no json data return None
        return None if not self.request else self.json

    """ Returns json of the previous page if available """
    def search_previous_page(self):
        if self.has_previous_page:
            self.__request(self.prev_page)
        else:
            return None
        # If there is no json data return None
        return None if not self.request else self.json

    """ Returns a list of photo objects """
    def get_photos(self):
        if not self.json:
            return None
        return [Photo(json_photo) for json_photo in self.json["photos"]]

    """ Returns a list of video objects """
    def get_videos(self):
        if not self.json:
            return None
        return [Video(json_video) for json_video in self.json["videos"]]

    """ Private methods """
    def __request(self, url):
        try:
            self.request = requests.get(url, timeout=10, headers=self.PEXELS_AUTHORIZATION)
            self.__update_page_properties()
        except requests.exceptions.RequestException:
            print("Request failed check your internet connection")
            self.request = None
            exit()
    def __update_page_properties(self):
        if self.request.ok:
            self.json = self.request.json()
            try:
                self.page = int(self.json["page"])
            except:
                self.page = None
            try:
                self.total_results = int(self.json["total_results"])
            except:
                self.total_results = None
            try:
                self.photo_results = len(self.json["photos"])
            except:
                self.photo_results = None
            try:
                self.video_results = len(self.json["videos"])
            except:
                self.video_results = None
            try:
                self.next_page = self.json["next_page"]
                self.has_next_page = True
            except:
                self.next_page = None
                self.has_next_page = False
            try:
                self.prev_page = self.json["prev_page"]
                self.has_previous_page = True
            except:
                self.prev_page = None
                self.has_previous_page = False
        else:
            print("Wrong response you might have a wrong API key")
            print(self.request)
            print("API key: {}".format(self.PEXELS_AUTHORIZATION))
            self.request = None
            exit()



# Pexels Website:   https://www.pexels.com
# class information:
#     Video's data stucture
class Video:
    def __init__(self, json_video):
        self.__video = json_video
    @property
    def id(self):
        return int(self.__video["id"])
    @property
    def width(self):
        return int(self.__video["width"])
    @property
    def height(self):
        return int(self.__video["height"])
    @property
    def url(self):
        return self.__video["url"]
    @property
    def image(self):
        return self.__video["image"]
    @property
    def duration(self):
        return self.__video["duration"]
    @property
    def userID(self):
        return int(self.__video["user"]["id"])
    @property
    def userName(self):
        return self.__video["user"]["name"]
    @property
    def userURL(self):
        return self.__video["user"]["url"]
    @property
    def videoFilesID(self):
        return int(self.__video["video_files"]["id"])
    @property
    def videoQuality(self):
        return self.__video["video_files"]["quality"]
    @property
    def videoFileType(self):
        return self.__video["video_files"]["file_type"]
    @property
    def videoFileWidth(self):
        return int(ideo["video_files"]["width"])
    @property
    def videoFilesHeight(self):
        return int(self.__video["video_files"]["height"])
    @property
    def videoFilesLink(self):
        return self.__video["video_files"]["link"]
    @property
    def videoPictures(self):
        return int(self.__video["video_pictures"]["id"])
    @property
    def videoPictures(self):
        return self.__video["video_pictures"]["picture"]
    @property
    def videoNumber(self):
        return int(self.__video["video_pictures"]["nr"])
    

    


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pexelsPy",
    version="1.0.1",
    author="Sravan Kumar",
    author_email="demonlyf98@protonmail.com",
    description="Use Pexels API v1 with Python",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/kingsamurai123/pexels-api",
    keywords='pexels api images photos videos python',
    install_requires=['requests'],
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    # python_requires='>=3',
)



# Pexels Website:   https://www.pexels.com
# class information:
#     Photo's data stucture
class Photo:
    def __init__(self, json_photo):
        self.__photo = json_photo
    @property
    def id(self):
        return int(self.__photo["id"])
    @property
    def width(self):
        return int(self.__photo["width"])
    @property
    def height(self):
        return int(self.__photo["height"])
    @property
    def photographer(self):
        return self.__photo["photographer"]
    @property
    def url(self):
        return self.__photo["url"]
    @property
    def description(self):
        return self.url.split("/")[-2].replace("-{}".format(self.id), "")
    @property
    def original(self):
        return self.__photo["src"]["original"]
    @property
    def compressed(self):
        return self.original + "?auto=compress"
    @property
    def large2x(self):
        return self.__photo["src"]["large2x"]
    @property
    def large(self):
        return self.__photo["src"]["large"]
    @property
    def medium(self):
        return self.__photo["src"]["medium"]
    @property
    def small(self):
        return self.__photo["src"]["small"]
    @property
    def portrait(self):
        return self.__photo["src"]["portrait"]
    @property
    def landscape(self):
        return self.__photo["src"]["landscape"]
    @property
    def tiny(self):
        return self.__photo["src"]["tiny"]
    @property
    def extension(self):
        return self.original.split(".")[-1]
